<!--
Types of changes:

* Added: for new features.
* Changed: for changes in existing functionality.
* Deprecated: for soon-to-be removed features.
* Dependencies: for changed / updated dependencies.
* Removed: for now removed features.
* Fixed: for any bug fixes.
* Security: in case of vulnerabilities.

Don’t forget to tag @ https://git.fitko.de/fit-connect/submission-api/-/tags
-->

# Submission API: Changelog

* The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
* If available, include a ticket number in format `(planning#XXXX)`.

## Unreleased

### Changed

* Erweiterung des destination Schemas um `senderAccessRestricted`, d.h. um die Möglichkeit, das Senden an diesen Zustellpunkt nur bestimmten Sendern zu erlauben ([planning#2534](https://git.fitko.de/fit-connect/planning/-/issues/2534)).

## [1.12.0]

### Added

- Erlaubt das Übertragen des optionalen Felds `region` bei `POST /v1/submissions`. Diese Erweiterung erlaubt es Anbindern,
  den amtlichen Regionalschlüssel (ARS) zusätzlich zu übertragen. Das optionale Feld wird, falls gesetzt, entsprechend
  auch bei `POST /v1/submissions`, `PUT /v1/submissions/{submissionId}` und `GET /v1/submissions/{submissionId}`
  im Response-Body zurückgegeben ([planning#2515](https://git.fitko.de/fit-connect/planning/-/issues/2515)).

## [1.11.0]

### Added

- Fügt die neuen Endpunkte `GET /v1/destinations/{destinationId}/limits` und `GET /v1/cases/{caseId}/limits` hinzu ([planning#2257](https://git.fitko.de/fit-connect/planning/-/issues/2257)).

## [1.10.0]

### Changed

- `send:region:...`-OAuth-Scopes wurden durch `https://schema.fitko.de/fit-connect/oauth/scopes/send-submissions` -Scopes ersetzt ([planning#2415](https://git.fitko.de/fit-connect/planning/-/issues/2415)).

### Added

- Wir ergänzen die Pipeline um [oasdiff](https://github.com/Tufin/oasdiff), damit wir frühzeitig `breaking changes` in einer neuen API-Version erkennen und verhindern können ([planning#2381](https://git.fitko.de/fit-connect/planning/-/issues/2381))

## [1.9.0]

### Added

- Die neuen Limits für gleichzeitige Up- und Downloads können zu einer HTTP 429 Response führen. Diese sind für die entsprechenden Endpunkte beschrieben worden ([planning#2166](https://git.fitko.de/fit-connect/planning/-/issues/2166))
- Der Rückkanal DeutschlandID (`idBundDeMailbox`) wurde hinzugefügt.

### Fixed

- Im `error`-Schema wurden die bisher nicht dokumentierten Felder `errorcode`, `violations` und `issue` aufgenommen ([planning#2246](https://git.fitko.de/fit-connect/planning/-/issues/2246)).
- In den Schemata `reply`, `destination-private` und `submission` wurde von `allOf` auf Inline-Properties umgestiegen.
Dies stell keine inhaltliche Änderung dar, aber verbessert die Tooling-Unterstützung der Spezifikation ([planning#2246](https://git.fitko.de/fit-connect/planning/-/issues/2246)).
- Das Feld `use` wird im JWK-Schema nun explizit aufgeführt, um eine strikte Übereinstimmung mit der Implementierung zu gewährleisten.
Fachlich erfüllt das Feld jedoch keinen Zweck, da sein Wert immer `null` ist ([planning#2246](https://git.fitko.de/fit-connect/planning/-/issues/2246)).

### Deprecated

* Der Rückkanal "FINK" (`fink`) wurde abgekündigt (deprecated)

## [1.8.0]

### Fixed

- Name der Destination wurde in Spezifikation aufgenommen (planning#2190)

## [1.7.0]

### Added

* Neue Endpunkte zum Abruf des event logs für eine Einreichung bzw. für eine Antwort ([planning#2089](https://git.fitko.de/fit-connect/planning/-/issues/2089)):
  * `get /v1/submissions/{submissionId}/events`
  * `get /v1/replies/{replyId}/events`

## [1.6.0]

### Changed

* Die Endpunkte unter "Internal" wurden entfernt. Analoge Endpunkte werden demnächst in einer separaten
"Destination API" ausgewiesen ([planning#1788](https://git.fitko.de/fit-connect/planning/-/issues/1788)).
* Kleinere Anpassungen wurden durchgeführt, um ein exaktes Übereinstimmen mit der Implementierung zu gewährleisten
([planning#2041](https://git.fitko.de/fit-connect/planning/-/issues/2041)):
  * Der Wert des `Cache-Control`-Headers wurde angepasst, um dem implementierten Verhalten zu entsprechen.
  * Beim `/v1/replies/{replyId}/accept`-Endpunkt wurde die vergessene `HTTP 422`-Response hinzugefügt.
  * `submission.encryptedData` und `submission.serviceType.description` sind nicht nur optionale Felder,
  sondern sie können auch mit `null` übermittelt werden. Tatsächlich gibt der Zustelldienst diese auch explizit
  als `null` zurück. Die Spezifikation wurde erweitert, um dieser feinen Unterscheidung Rechnung zu tragen.

## [1.5.0]

### Changed

* Die Einträge unter `callbacks` wurden nach `webhooks` verschoben. Diese Änderung soll das tatsächliche Versenden
von Benachrichtigungen verständlicher dokumentieren. ([planning#1850](https://git.fitko.de/fit-connect/planning/-/issues/1850))

## [1.4.2]

### Changed

* Die Reihenfolge von Elementen in Listen-Endpunkten wird nun verbal klarer spezifiziert ([planning#1653](https://git.fitko.de/fit-connect/planning/-/issues/1653)).

## [1.4.1]

### Changed

* Die `keyId` von `GET /v1/destinations/{destinationId}/keys/{keyId}` hat nun eine Länge von 8-64 Zeichen (zuvor 8-36). ([planning#1904](https://git.fitko.de/fit-connect/planning/-/issues/1904))
* Das Feld `encryptionKid` einer Destination hat nun eine Minimallänge von 8 Zeichen.

## [1.4.0]

### Changed

* Die Scopes `manage:destination:<id>` und `subscribe:destination:<id>` wurden umbenannt.
  * `manage:destination:<id>` ➡ `https://schema.fitko.de/fit-connect/oauth/scopes/manage-destinations`
  * `subscribe:destination:<id>` ➡ `https://schema.fitko.de/fit-connect/oauth/scopes/subscribe-destinations`
  Die Autorisierungsprüfung wird nun nicht mehr über die IDs der Destinations im Token erledigt.
  Für API-Clients ist diese Änderung transparent.
  Die veränderten Scopes bei bestehenden API-Clients werden migriert.
* [NO\_PUBLIC] Updated @redocly/cli to 1.10.x
* [NO\_PUBLIC] Use FITKO GitLab docker registry. [(planning#1754)](https://git.fitko.de/fit-connect/planning/-/issues/1754)
* [NO\_PUBLIC] The Submission API Specification is now bundled by [redocly-cli](https://redocly.com/docs/cli/) instead of swagger-cli (discontinued).
  This should not affect the specification semantically but has changed the bundled document structure in certain aspects. [(planning#1409)](https://git.fitko.de/fit-connect/planning/-/issues/1409)
* [NO\_PUBLIC] Updated RapiDoc to 9.3.4
* Commits auf dem `main` Branch werden nun auf [latest-dev](https://schema.fitko.de/fit-connect/submission-api/latest-dev/) released. ([planning#1746](https://git.fitko.de/fit-connect/planning/-/issues/1746))
* Releases werden nun, zusätzlich zum Pfad mit der Versionsnummer, auch auf [latest](https://schema.fitko.de/fit-connect/submission-api/latest) released. ([planning#1746](https://git.fitko.de/fit-connect/planning/-/issues/1746))
* Duplizierte Schemadefinitionen wurden entfernt und sind jetzt im Format _dash-case_, also `create-reply` statt `CreateReply`.
  Für API-Clients ist diese Änderung transparent, da sich das Verhalten der API sonst nicht ändert.
  Codegeneratoren müssen eventuell angepasst werden.
* Einführung des neuen Scopes `https://schema.fitko.de/fit-connect/oauth/scopes/read-all-event-logs`, um den Support zu verbessern ([planning#1745](https://git.fitko.de/fit-connect/planning/-/issues/1745))
* Vereinheitlichung der Response-Bodies für die Erstellung und den Versand von Einreichungen (([planning#291](https://git.fitko.de/fit-connect/planning/-/issues/291)))
  * `POST /v1/submissions` und `POST /v1/submissions/{submissionId}` geben nun einen einheitlichen Response-Body zurück.
  * Auf die Übernahme des callback-Felds aus `submission-reduced` in das `submission-created`-Schema wurde verzichtet, da es bereits als deprecated markiert ist.

## [1.3.0]

### Added

* The Submission API now has a new case management section since the bidirectional communication feature
  adds more focus on cases. [(planning#460)](https://git.fitko.de/fit-connect/planning/-/issues/460)
* The Submission API grew by two endpoints to retrieve a case / list all cases [(planning#460)](https://git.fitko.de/fit-connect/planning/-/issues/460):
  * [`http get /v1/cases/<caseId>`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#get-/v1/cases/-caseId-)
  * [`http get /v1/cases`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#get-/v1/cases)
* The Submission API grew by several endpoints to manage / create / handle replies, a new top-level entity [(planning#460)](https://git.fitko.de/fit-connect/planning/-/issues/460):
  * [`http get /v1/replies`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#get-/v1/replies) to list replies
  * [`http post /v1/replies`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#post-/v1/replies) to create a reply
  * [`http get /v1/replies/<replyId>`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#get-/v1/replies/-replyId-) to get a specific reply
  * [`http put /v1/replies/<replyId>`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#put-/v1/replies/-replyId-) to submit a reply
  * [`http put /v1/replies/<replyId>/accept`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#put-/v1/replies/-replyId-/accept) to accept a reply (as an online service)
  * [`http put /v1/replies/<replyId>/reject`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#put-/v1/replies/-replyId-/reject) to reject a reply (as an online service)
  * [`http get /v1/replies/<replyId>/attachments/<attachmentId>`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#get-/v1/replies/-replyId-/attachments/-attachmentId-) to get a reply attachment
  * [`http put /v1/replies/<replyId>/attachments/<attachmentId>`](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#put-/v1/replies/-replyId-/attachments/-attachmentId-) to upload a reply attachment
* Similar to the [NewSubmissions callback](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#post-/v1/destinations),
  the Submission API now has a [NewReplies callback](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#post-/v1/submissions) that gets called
  every time a new reply is added to a case. [(planning#460)](https://git.fitko.de/fit-connect/planning/-/issues/460)
* To enable bidirectional communication, an additional reply channel was added: `fitConnect`.
  If a [destination supports](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#post-/v1/destinations) the `fitConnect` reply channel,
  an [online service may select it via the Metadata `replyChannel -> fitConnect`](https://docs.fitko.de/fit-connect/docs/metadata/overview/).
  For more details, check the [official FIT-Connect documentation](https://docs.fitko.de/fit-connect/docs/). [(planning#460)](https://git.fitko.de/fit-connect/planning/-/issues/460)

### Changed

* The Submission API now uses [OpenAPI 3.1.0](https://spec.openapis.org/oas/v3.1.0).
* Consolidated Attachment and CreateAttachment entities to a common type JWE.
  This might be relevant for code generation tools.
  The content stays the same though.
* Updated lots of descriptions and examples.
  If you find more errors, please report them to [OpenCode](https://gitlab.opencode.de/fitko/feedback/-/issues).
* The [NewEvents callback](https://docs.fitko.de/fit-connect/docs/apis/submission-api?version=1.3.0#post-/v1/destinations) may now include
  a list of replies in the field `replies`. [(planning#460)](https://git.fitko.de/fit-connect/planning/-/issues/460)

### Fixed

* Only CORS requests receive CORS headers. [(planning#501)](https://git.fitko.de/fit-connect/planning/-/issues/501)

## [1.2.1]

* Baseline changelog.
  Check GIT history for a changelog of this and earlier versions.
