# FIT-Connect API specification

* Live Version: https://docs.fitko.de/fit-connect/docs/apis/submission-api

## Rules

### General

- We use OpenAPI 3.1.0
- The specification is written in YAML.
- The specification adheres to [Semver](https://semver.org/).

### Identifiers

- Fields etc. are written in `camelCase`.
- Short identifiers are written as `Id` and not `ID`.

## "Magic" numbers

- `683`: Minimum length of the modulus (`n`) of a JWK with a `4096` bit RSA key.
  See https://git.fitko.de/fit-connect/submission-api/-/snippets/1.
- `776`: Minimum length of a JWE in compact serialization. No payload. Content encryption with `A256GCM`. Key encryption
  with `RSA-OAEP-256` and a `4096` bit RSA key.
  See https://git.fitko.de/fit-connect/examples/-/blob/main/java/crypto/src/main/java/ExampleJweEncryption.java

## Consistent identifiers

To make the examples in `spec/examples` more consistent, we use the following fixed identifiers.
Exceptions:

* lists with several different IDs
* examples that are semantically different

If you use a new identifier, please make sure it differs in the first character since this makes it easier to read.

| ID              | Value                                  |
|-----------------|----------------------------------------|
| `caseId`        | `e89e107e-ed79-40e6-ad34-4e770f9df263` |
| `destinationId` | `879ee109-a690-4db8-ab32-424284184d7d` |
| `submissionId`  | `ce75a6b8-d72f-4b94-b09e-af6be35bc2ae` |
| `replyId`       | `b9715dcb-700e-44d9-802f-12b45bf9f8a3` |

### Submission `ce75a6b8-d72f-4b94-b09e-af6be35bc2ae`

Attachments:

- `879ee109-a690-4db8-ab32-424284184d7d`
- `2046f9f1-dc89-4440-9c24-c76a8f40d668`

### Reply `b9715dcb-700e-44d9-802f-12b45bf9f8a3`

Attachments:

- `2d8cef0c-62e1-4936-925c-2da79377d29c`
- `fa9e16fc-0cb1-4d14-9a9a-4130fa51083f`
